@@ -327,31 +327,27 @@ class Experimento:
                                            categoria="aceleracion",
                                            serie=self.serie_aceleracion)
 
-    def calcula_entropias(self, tamanio_vectores, traslape):
+    def calcula_entropias(self, tamanio_vectores, umbral):
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="histograma_velocidad",
                                        datos=self.histogramas["velocidad"])
 
-        """
         m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
                                                   categoria="aproximada_velocidad",
                                                   datos=self.serie_velocidad.to_numpy(),
                                                   tamanio_vectorial=tamanio_vectores,
-                                                  traslape=traslape)
-                                                  """
+                                                  umbral=umbral)
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="histograma_aceleracion",
                                        datos=self.histogramas["aceleracion"])
 
-        """
         m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
                                                   categoria="aproximada_aceleracion",
                                                   datos=self.serie_aceleracion.to_numpy(),
                                                   tamanio_vectorial=tamanio_vectores,
-                                                  traslape=traslape)
-        """
+                                                  umbral=umbral)
 
     def calcula_velocidades_promediadas(self, cantidad_datos_promedio):
         print("-------------------------------------------------------------")
