@@ -15,7 +15,6 @@ class MultiplesExperimentos:
                  puntos_importantes=None,
                  objeto_a_promediar=1,
                  tamanio_intervalo_para_promedio=100,
-                 arreglo_regiones_preferidas="",
                  epsilon_distancias_pendientes=1):
         self.lista_archivos = lista_archivos
         self.lista_experimentos = list()
@@ -23,7 +22,6 @@ class MultiplesExperimentos:
         self.resultados_divergencia = dict()
         self.pendientes_regresion_lineal = dict()
         self.resultados_pendientes_regresion_lineal = dict()
-        self.arreglo_regiones_preferidas = arreglo_regiones_preferidas
 
         if dimension_caja is None:
             self.dimension_caja = [100, 100]
@@ -74,9 +72,14 @@ class MultiplesExperimentos:
         for experimento in self.lista_experimentos:
             experimento.calcula_velocidades()
 
-    def calcula_entropias_divergencias(self, tamanio_vectores=2, traslape=3):
+    def calcula_regiones_cuadriculadas(self, arreglo_regiones_preferidas):
         for experimento in self.lista_experimentos:
-            experimento.calcula_entropias(tamanio_vectores, traslape)
+            experimento.calcula_regiones_cuadriculadas()
+            experimento.calcula_matrices_solo_regiones_preferidas(regiones_preferidas=arreglo_regiones_preferidas)
+
+    def calcula_entropias_divergencias(self, tamanio_vectores=2, umbral=3):
+        for experimento in self.lista_experimentos:
+            experimento.calcula_entropias(tamanio_vectores, umbral)
 
     def calcula_regresiones_lineales(self, brinco_temporal, longitud_ventana_tiempo):
         for experimento in self.lista_experimentos:
@@ -92,6 +95,28 @@ class MultiplesExperimentos:
                 procesador.agrega_categoria_regresion_lineal(experimento.regresiones_lineales,
                                                              tipo_arreglo)
 
+    def procesa_pendientes(self):
+        experimento_inicial = self.lista_experimentos[0]
+
+        for tipo_regresion_lineal in sorted(experimento_inicial.regresiones_lineales):
+            lista_pendientes = []
+            for experimento in self.lista_experimentos:
+                diccionario_regresion_lineal_experimento = experimento.regresiones_lineales[tipo_regresion_lineal]
+                pendiente_experimento = diccionario_regresion_lineal_experimento["pendientes"]
+                lista_pendientes.append(pendiente_experimento)
+            self.pendientes_regresion_lineal[tipo_regresion_lineal] = lista_pendientes
+
+    def procesa_distancias_pendientes(self, epsilon):
+        print("-------------------------------------------------------------------------------")
+        for tipo_regresion_lineal in sorted(self.pendientes_regresion_lineal):
+            print("Regresión lineal a procesar distancias pendientes: ", tipo_regresion_lineal)
+            lista_pendientes = self.pendientes_regresion_lineal[tipo_regresion_lineal]
+            print("Lista de pendientes para", tipo_regresion_lineal, ": ", lista_pendientes)
+            resultados_pendientes_funcion_signo = m_dp.procesa_lista_pendientes_funcion_signo(lista_pendientes,
+                                                                                              epsilon)
+            resultados_distancias = m_dp.calcula_distancias_para_lista_pendientes(resultados_pendientes_funcion_signo)
+            self.resultados_pendientes_regresion_lineal[tipo_regresion_lineal] = resultados_distancias
+
     def procesa_diccionario_entropias(self):
         """
         Se lee uno de los diccionarios de entropía para conocer sus llaves. Por cada llave, se obtienen todos
@@ -111,25 +136,6 @@ class MultiplesExperimentos:
                 valores_entropia.append(valor_entropia_experimento)
             self.resultados_entropia[tipo_entropia] = valores_entropia
 
-    def procesa_pendientes(self):
-        experimento_inicial = self.lista_experimentos[0]
-
-        for tipo_regresion_lineal in sorted(experimento_inicial.regresiones_lineales):
-            lista_pendientes = []
-            for experimento in self.lista_experimentos:
-                diccionario_regresion_lineal_experimento = experimento.regresiones_lineales[tipo_regresion_lineal]
-                pendiente_experimento = diccionario_regresion_lineal_experimento["pendientes"]
-                lista_pendientes.append(pendiente_experimento)
-            self.pendientes_regresion_lineal[tipo_regresion_lineal] = lista_pendientes
-
-    def procesa_distancias_pendiente(self, epsilon):
-        for tipo_regresion_lineal in sorted(self.resultados_pendientes_regresion_lineal):
-            lista_pendientes = self.pendientes_regresion_lineal[tipo_regresion_lineal]
-            resultados_pendientes_funcion_signo = m_dp.procesa_lista_pendientes_funcion_signo(lista_pendientes,
-                                                                                              epsilon)
-            resultados_distancias = m_dp.calcula_distancias_para_lista_pendientes(resultados_pendientes_funcion_signo)
-            self.resultados_pendientes_regresion_lineal[tipo_regresion_lineal] = resultados_distancias
-
     def procesa_diccionario_divergencias(self):
         lista_arreglos_regiones = list()
         lista_arreglos_solo_regiones_preferidas = list()
