@@ -2,6 +2,7 @@ class InformacionRutasVectoriales:
     def __init__(self, posiciones_eje_x=None, posiciones_eje_y=None,
                  tamanio_vectorial=None, brinco_temporal=None,
                  indice_consecuencia=None):
+
         self.posiciones_eje_x = posiciones_eje_x
         self.posiciones_eje_y = posiciones_eje_y
         self.tamanio_vectorial = tamanio_vectorial
@@ -17,10 +18,16 @@ class InformacionRutasVectoriales:
         self.posiciones_x_despues_consecuencia = None
         self.posiciones_y_despues_consecuencia = None
 
-        self.direcciones_x_antes_consecuencias = None
-        self.direcciones_y_antes_consecuencias = None
-        self.direcciones_x_despues_consecuencias = None
-        self.direcciones_y_despues_consecuencias = None
+        self.direcciones_x_antes_consecuencia = None
+        self.direcciones_y_antes_consecuencia = None
+        self.direcciones_x_despues_consecuencia = None
+        self.direcciones_y_despues_consecuencia = None
+
+    def procesar_informacion_vectorial(self):
+        self.obtener_posiciones_vectores()
+
+        self.obtener_direcciones_vectores()
+
 
     def obtener_posiciones_vectores(self):
         self.posiciones_x_antes_consecuencia, self.posiciones_x_despues_consecuencia = \
@@ -29,12 +36,24 @@ class InformacionRutasVectoriales:
                                                               self.tamanio_vectorial,
                                                               self.brinco_temporal)
 
+        self.posiciones_y_antes_consecuencia, self.posiciones_y_despues_consecuencia = \
+            obtener_posiciones_correspondientes_direccion_eje(self.posiciones_eje_y,
+                                                              self.indice_consecuencia,
+                                                              self.tamanio_vectorial,
+                                                              self.brinco_temporal)
+
+        self.posiciones_x_antes_consecuencia_con_consecuencia = self.posiciones_x_antes_consecuencia.copy()
+        self.posiciones_x_antes_consecuencia_con_consecuencia.append(self.posiciones_eje_x[self.indice_consecuencia])
+
+        self.posiciones_y_antes_consecuencia_con_consecuencia =  self.posiciones_y_antes_consecuencia.copy()
+        self.posiciones_y_antes_consecuencia_con_consecuencia.append(self.posiciones_eje_y[self.indice_consecuencia])
+
     def obtener_direcciones_vectores(self):
-        self.direcciones_x_antes_consecuencias, self.direcciones_y_antes_consecuencias = \
+        self.direcciones_x_antes_consecuencia, self.direcciones_y_antes_consecuencia = \
             obtener_vectores_posicion_flechas(self.posiciones_x_antes_consecuencia_con_consecuencia,
                                               self.posiciones_y_antes_consecuencia_con_consecuencia)
 
-        self.direcciones_x_despues_consecuencias, self.direcciones_y_despues_consecuencias,\
+        self.direcciones_x_despues_consecuencia, self.direcciones_y_despues_consecuencia =\
             obtener_vectores_posicion_flechas(self.posiciones_x_despues_consecuencia,
                                               self.posiciones_y_despues_consecuencia)
 
@@ -45,17 +64,16 @@ class InformacionRutasVectoriales:
         arreglo_posiciones_y = [self.posiciones_y_antes_consecuencia,
                                 self.posiciones_y_despues_consecuencia]
 
-        arreglo_direcciones_x = [self.direcciones_x_antes_consecuencias,
-                                 self.direcciones_x_despues_consecuencias]
+        arreglo_direcciones_x = [self.direcciones_x_antes_consecuencia,
+                                 self.direcciones_x_despues_consecuencia]
 
-        arreglo_direcciones_y = [self.direcciones_y_antes_consecuencias,
-                                 self.direcciones_y_despues_consecuencias]
+        arreglo_direcciones_y = [self.direcciones_y_antes_consecuencia,
+                                 self.direcciones_y_despues_consecuencia]
 
         return arreglo_posiciones_x, arreglo_posiciones_y, \
                arreglo_direcciones_x, arreglo_direcciones_y
 
 
-
 def obtener_vectores_posicion_flechas(vector_x, vector_y):
     x_direct = []
     y_direct = []
@@ -94,6 +112,3 @@ def obtener_posiciones_correspondientes_direccion_eje(posiciones_eje_correspondi
                                                         int(brinco_temporal)]
 
     return pos_antes_consecuencia, pos_despues_consecuencia
-
-
-
